    from quickfix import *

    class MyStringField(quickfix.StringField):
            def __init__(self, data = None)
                    if data == None:
                            quickfix.StringField.__init__(self, 6123)
                    else:
                            quickfix.StringField.__init__(self, 6123, data)

    class MyPriceField(quickfix.DoubleField):
            def __init__(self, data = None)
                    if data == None:
                            quickfix.DoubleField.__init__(self, 8756)
                    else:
                            quickfix.DoubleField.__init__(self, 8756, data)